Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindRequestExpansion ¶
type BindRequestExpansion interface{}
type BindRequestInterface ¶
type BindRequestInterface interface {
Create(ctx context.Context, bindRequest *schedulingv1alpha2.BindRequest, opts v1.CreateOptions) (*schedulingv1alpha2.BindRequest, error)
Update(ctx context.Context, bindRequest *schedulingv1alpha2.BindRequest, opts v1.UpdateOptions) (*schedulingv1alpha2.BindRequest, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, bindRequest *schedulingv1alpha2.BindRequest, opts v1.UpdateOptions) (*schedulingv1alpha2.BindRequest, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*schedulingv1alpha2.BindRequest, error)
List(ctx context.Context, opts v1.ListOptions) (*schedulingv1alpha2.BindRequestList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *schedulingv1alpha2.BindRequest, err error)
BindRequestExpansion
}
BindRequestInterface has methods to work with BindRequest resources.
type BindRequestsGetter ¶
type BindRequestsGetter interface {
BindRequests(namespace string) BindRequestInterface
}
BindRequestsGetter has a method to return a BindRequestInterface. A group's client should implement this interface.
type SchedulingV1alpha2Client ¶
type SchedulingV1alpha2Client struct {
// contains filtered or unexported fields
}
SchedulingV1alpha2Client is used to interact with features provided by the scheduling.run.ai group.
func New ¶
func New(c rest.Interface) *SchedulingV1alpha2Client
New creates a new SchedulingV1alpha2Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SchedulingV1alpha2Client, error)
NewForConfig creates a new SchedulingV1alpha2Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new SchedulingV1alpha2Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SchedulingV1alpha2Client
NewForConfigOrDie creates a new SchedulingV1alpha2Client for the given config and panics if there is an error in the config.
func (*SchedulingV1alpha2Client) BindRequests ¶
func (c *SchedulingV1alpha2Client) BindRequests(namespace string) BindRequestInterface
func (*SchedulingV1alpha2Client) RESTClient ¶
func (c *SchedulingV1alpha2Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type SchedulingV1alpha2Interface ¶
type SchedulingV1alpha2Interface interface {
RESTClient() rest.Interface
BindRequestsGetter
}