Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type QueueExpansion ¶
type QueueExpansion interface{}
type QueueInterface ¶
type QueueInterface interface {
Create(ctx context.Context, queue *schedulingv2.Queue, opts v1.CreateOptions) (*schedulingv2.Queue, error)
Update(ctx context.Context, queue *schedulingv2.Queue, opts v1.UpdateOptions) (*schedulingv2.Queue, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, queue *schedulingv2.Queue, opts v1.UpdateOptions) (*schedulingv2.Queue, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*schedulingv2.Queue, error)
List(ctx context.Context, opts v1.ListOptions) (*schedulingv2.QueueList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *schedulingv2.Queue, err error)
QueueExpansion
}
QueueInterface has methods to work with Queue resources.
type QueuesGetter ¶
type QueuesGetter interface {
Queues(namespace string) QueueInterface
}
QueuesGetter has a method to return a QueueInterface. A group's client should implement this interface.
type SchedulingV2Client ¶
type SchedulingV2Client struct {
// contains filtered or unexported fields
}
SchedulingV2Client is used to interact with features provided by the scheduling.run.ai group.
func New ¶
func New(c rest.Interface) *SchedulingV2Client
New creates a new SchedulingV2Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SchedulingV2Client, error)
NewForConfig creates a new SchedulingV2Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new SchedulingV2Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SchedulingV2Client
NewForConfigOrDie creates a new SchedulingV2Client for the given config and panics if there is an error in the config.
func (*SchedulingV2Client) Queues ¶
func (c *SchedulingV2Client) Queues(namespace string) QueueInterface
func (*SchedulingV2Client) RESTClient ¶
func (c *SchedulingV2Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type SchedulingV2Interface ¶
type SchedulingV2Interface interface {
RESTClient() rest.Interface
QueuesGetter
}