Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PodGroupExpansion ¶
type PodGroupExpansion interface{}
type PodGroupInterface ¶
type PodGroupInterface interface {
Create(ctx context.Context, podGroup *schedulingv2alpha2.PodGroup, opts v1.CreateOptions) (*schedulingv2alpha2.PodGroup, error)
Update(ctx context.Context, podGroup *schedulingv2alpha2.PodGroup, opts v1.UpdateOptions) (*schedulingv2alpha2.PodGroup, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, podGroup *schedulingv2alpha2.PodGroup, opts v1.UpdateOptions) (*schedulingv2alpha2.PodGroup, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*schedulingv2alpha2.PodGroup, error)
List(ctx context.Context, opts v1.ListOptions) (*schedulingv2alpha2.PodGroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *schedulingv2alpha2.PodGroup, err error)
PodGroupExpansion
}
PodGroupInterface has methods to work with PodGroup resources.
type PodGroupsGetter ¶
type PodGroupsGetter interface {
PodGroups(namespace string) PodGroupInterface
}
PodGroupsGetter has a method to return a PodGroupInterface. A group's client should implement this interface.
type SchedulingV2alpha2Client ¶
type SchedulingV2alpha2Client struct {
// contains filtered or unexported fields
}
SchedulingV2alpha2Client is used to interact with features provided by the scheduling.run.ai group.
func New ¶
func New(c rest.Interface) *SchedulingV2alpha2Client
New creates a new SchedulingV2alpha2Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SchedulingV2alpha2Client, error)
NewForConfig creates a new SchedulingV2alpha2Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new SchedulingV2alpha2Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SchedulingV2alpha2Client
NewForConfigOrDie creates a new SchedulingV2alpha2Client for the given config and panics if there is an error in the config.
func (*SchedulingV2alpha2Client) PodGroups ¶
func (c *SchedulingV2alpha2Client) PodGroups(namespace string) PodGroupInterface
func (*SchedulingV2alpha2Client) RESTClient ¶
func (c *SchedulingV2alpha2Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type SchedulingV2alpha2Interface ¶
type SchedulingV2alpha2Interface interface {
RESTClient() rest.Interface
PodGroupsGetter
}