v1alpha2

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewBindRequestInformer

func NewBindRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewBindRequestInformer constructs a new informer for BindRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredBindRequestInformer

func NewFilteredBindRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredBindRequestInformer constructs a new informer for BindRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type BindRequestInformer

type BindRequestInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() schedulingv1alpha2.BindRequestLister
}

BindRequestInformer provides access to a shared informer and lister for BindRequests.

type Interface

type Interface interface {
	// BindRequests returns a BindRequestInformer.
	BindRequests() BindRequestInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

Jump to