Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type QueueLister ¶
type QueueLister interface {
// List lists all Queues in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*schedulingv2.Queue, err error)
// Queues returns an object that can list and get Queues.
Queues(namespace string) QueueNamespaceLister
QueueListerExpansion
}
QueueLister helps list Queues. All objects returned here must be treated as read-only.
func NewQueueLister ¶
func NewQueueLister(indexer cache.Indexer) QueueLister
NewQueueLister returns a new QueueLister.
type QueueListerExpansion ¶
type QueueListerExpansion interface{}
QueueListerExpansion allows custom methods to be added to QueueLister.
type QueueNamespaceLister ¶
type QueueNamespaceLister interface {
// List lists all Queues in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*schedulingv2.Queue, err error)
// Get retrieves the Queue from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*schedulingv2.Queue, error)
QueueNamespaceListerExpansion
}
QueueNamespaceLister helps list and get Queues. All objects returned here must be treated as read-only.
type QueueNamespaceListerExpansion ¶
type QueueNamespaceListerExpansion interface{}
QueueNamespaceListerExpansion allows custom methods to be added to QueueNamespaceLister.
Click to show internal directories.
Click to hide internal directories.