integration_tests_utils

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunTest

func RunTest(t *testing.T, testMetadata TestTopologyMetadata, testNumber int, controller *Controller)

func RunTests

func RunTests(t *testing.T, testsMetadata []TestTopologyMetadata)

func SetSchedulerActions

func SetSchedulerActions()

Types

type TestTopologyMetadata

type TestTopologyMetadata struct {
	Name string
	test_utils.TestTopologyBasic
	RoundsUntilMatch   int
	RoundsAfterMatch   int           // Used in order to verify the test scenario remain (no allocation/delete loop)
	SchedulingDuration time.Duration // Used to specify delay between rounds, leave empty if not needed
}

Jump to