Documentation
¶
Index ¶
- Constants
- func Duration(start time.Time) time.Duration
- func IncPodgroupScheduledByAction()
- func IncPodgroupsConsideredByAction()
- func IncScenarioFilteredByAction()
- func IncScenarioSimulatedByAction()
- func InitMetrics(namespace string)
- func RecordPodGroupEvictedPods(name, namespace, uid, nodepool, action string, count int)
- func RegisterPreemptionAttempts()
- func ResetQueueFairShare()
- func ResetQueueUsage()
- func SetCurrentAction(action string)
- func UpdateActionDuration(actionName string, duration time.Duration)
- func UpdateCloseSessionDuration(startTime time.Time)
- func UpdateE2eDuration(startTime time.Time)
- func UpdateOpenSessionDuration(startTime time.Time)
- func UpdatePluginDuration(pluginName, OnSessionStatus string, duration time.Duration)
- func UpdateQueueFairShare(queueName string, cpu, memory, gpu float64)
- func UpdateQueueUsage(queueName string, cpu, memory, gpu float64)
- func UpdateTaskBindDuration(startTime time.Time)
- func UpdateTaskScheduleDuration(duration time.Duration)
- func UpdateUsageQueryLatency(latency time.Duration)
Constants ¶
const ( // OnSessionOpen label OnSessionOpen = "OnSessionOpen" // OnSessionClose label OnSessionClose = "OnSessionClose" )
Variables ¶
This section is empty.
Functions ¶
func IncPodgroupScheduledByAction ¶
func IncPodgroupScheduledByAction()
func IncPodgroupsConsideredByAction ¶
func IncPodgroupsConsideredByAction()
func IncScenarioFilteredByAction ¶
func IncScenarioFilteredByAction()
func IncScenarioSimulatedByAction ¶
func IncScenarioSimulatedByAction()
func InitMetrics ¶ added in v0.4.6
func InitMetrics(namespace string)
func RecordPodGroupEvictedPods ¶ added in v0.13.0
RecordPodGroupEvictedPods records the number of pods evicted for a pod group
func RegisterPreemptionAttempts ¶
func RegisterPreemptionAttempts()
RegisterPreemptionAttempts records number of attempts for preemption
func ResetQueueFairShare ¶
func ResetQueueFairShare()
func ResetQueueUsage ¶ added in v0.8.2
func ResetQueueUsage()
func SetCurrentAction ¶
func SetCurrentAction(action string)
func UpdateActionDuration ¶
UpdateActionDuration updates latency for every action
func UpdateCloseSessionDuration ¶
UpdateCloseSessionDuration updates latency for close session, including all plugins
func UpdateE2eDuration ¶
UpdateE2eDuration updates entire end to end scheduling latency
func UpdateOpenSessionDuration ¶
UpdateOpenSessionDuration updates latency for open session, including all plugins
func UpdatePluginDuration ¶
UpdatePluginDuration updates latency for every plugin
func UpdateQueueFairShare ¶
UpdateQueueFairShare updates fair share of queue for a resource
func UpdateQueueUsage ¶ added in v0.8.2
UpdateQueueUsage updates usage of queue for a resource
func UpdateTaskBindDuration ¶
UpdateTaskBindDuration updates single task bind latency, including bind request creation
func UpdateTaskScheduleDuration ¶
UpdateTaskScheduleDuration updates single task scheduling latency
func UpdateUsageQueryLatency ¶ added in v0.8.3
Types ¶
This section is empty.