Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BindRequestLister ¶
type BindRequestLister interface {
// List lists all BindRequests in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*schedulingv1alpha2.BindRequest, err error)
// BindRequests returns an object that can list and get BindRequests.
BindRequests(namespace string) BindRequestNamespaceLister
BindRequestListerExpansion
}
BindRequestLister helps list BindRequests. All objects returned here must be treated as read-only.
func NewBindRequestLister ¶
func NewBindRequestLister(indexer cache.Indexer) BindRequestLister
NewBindRequestLister returns a new BindRequestLister.
type BindRequestListerExpansion ¶
type BindRequestListerExpansion interface{}
BindRequestListerExpansion allows custom methods to be added to BindRequestLister.
type BindRequestNamespaceLister ¶
type BindRequestNamespaceLister interface {
// List lists all BindRequests in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*schedulingv1alpha2.BindRequest, err error)
// Get retrieves the BindRequest from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*schedulingv1alpha2.BindRequest, error)
BindRequestNamespaceListerExpansion
}
BindRequestNamespaceLister helps list and get BindRequests. All objects returned here must be treated as read-only.
type BindRequestNamespaceListerExpansion ¶
type BindRequestNamespaceListerExpansion interface{}
BindRequestNamespaceListerExpansion allows custom methods to be added to BindRequestNamespaceLister.
Click to show internal directories.
Click to hide internal directories.