Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunTest ¶
func RunTest(t *testing.T, testMetadata TestTopologyMetadata, testNumber int, controller *Controller)
func RunTests ¶
func RunTests(t *testing.T, testsMetadata []TestTopologyMetadata)
func SetSchedulerActions ¶
func SetSchedulerActions()
Types ¶
type TestTopologyMetadata ¶
type TestTopologyMetadata struct {
Name string
test_utils.TestTopologyBasic
RoundsUntilMatch int
RoundsAfterMatch int // Used in order to verify the test scenario remain (no allocation/delete loop)
SchedulingDuration time.Duration // Used to specify delay between rounds, leave empty if not needed
}
Click to show internal directories.
Click to hide internal directories.