Documentation
¶
Overview ¶
Package k8s_utils is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func StringResourceList ¶ added in v0.4.13
func StringResourceList(resources v1.ResourceList) string
Types ¶
type Interface ¶
type Interface interface {
PatchPodAnnotationsAndLabelsInterface(
kubeclient kubernetes.Interface, pod *v1.Pod, annotations, labels map[string]interface{},
) error
}
var Helpers Interface = &K8sHelpers{}
type K8sHelpers ¶
type K8sHelpers struct{}
func (*K8sHelpers) PatchPodAnnotationsAndLabelsInterface ¶
func (_k8s *K8sHelpers) PatchPodAnnotationsAndLabelsInterface( kubeclient kubernetes.Interface, pod *v1.Pod, annotations, labels map[string]interface{}, ) error
PatchPodAnnotationsAndLabelsInterface allows to delete keys from annotations and labels dicts
type MockInterface ¶
type MockInterface struct {
// contains filtered or unexported fields
}
MockInterface is a mock of Interface interface.
func NewMockInterface ¶
func NewMockInterface(ctrl *gomock.Controller) *MockInterface
NewMockInterface creates a new mock instance.
func (*MockInterface) EXPECT ¶
func (m *MockInterface) EXPECT() *MockInterfaceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockInterface) PatchPodAnnotationsAndLabelsInterface ¶
func (m *MockInterface) PatchPodAnnotationsAndLabelsInterface(kubeclient kubernetes.Interface, pod *v1.Pod, annotations, labels map[string]any) error
PatchPodAnnotationsAndLabelsInterface mocks base method.
type MockInterfaceMockRecorder ¶
type MockInterfaceMockRecorder struct {
// contains filtered or unexported fields
}
MockInterfaceMockRecorder is the mock recorder for MockInterface.
func (*MockInterfaceMockRecorder) PatchPodAnnotationsAndLabelsInterface ¶
func (mr *MockInterfaceMockRecorder) PatchPodAnnotationsAndLabelsInterface(kubeclient, pod, annotations, labels any) *gomock.Call
PatchPodAnnotationsAndLabelsInterface indicates an expected call of PatchPodAnnotationsAndLabelsInterface.
Click to show internal directories.
Click to hide internal directories.